LMFeedIcon class

A simple icon widget to be used throughout the feed Represents three types of icons - icon, png, svg Provides customisability through LMFeedIconStyle

Inheritance

Constructors

LMFeedIcon({Key? key, required LMFeedIconType type, String? assetPath, IconData? icon, LMFeedIconStyle? style})
either the icon IconData or asset path String must be provided
const

Properties

assetPath String?
if LMFeedIconType.png or LMFeedIconType.svg then pass path of icon String
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData?
if LMFeedIconType.icon then pass icon of type IconData
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style LMFeedIconStyle?
style class for styling the icon LMFeedIconStyle
final
type LMFeedIconType
enum describing the type of icon to be shown
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
copyWith({LMFeedIconType? type, IconData? icon, String? assetPath, LMFeedIconStyle? style}) LMFeedIcon
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
getIconWidget(LMFeedIconStyle style) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited